==> ldtp_2.2.0.orig.tar.gz: ldtp-2.2.0/ldtp/state.py <==
"""
LDTP v2 client

@author: Nagappan Alagappan <nagappan@gmail.com>
@copyright: Copyright (c) 2009-11 Nagappan Alagappan
@license: LGPL

http://ldtp.freedesktop.org

This file may be distributed and/or modified under the terms of the GNU General
Public License version 2 as published by the Free Software Foundation. This file
is distributed without any warranty; without even the implied warranty of 
merchantability or fitness for a particular purpose.

See 'COPYING' in the source distribution for more information.

Headers in this file shall remain intact.
"""

ICONIFIED = "iconified"
INVALID = "invalid"
PRESSED = "pressed"
EXPANDABLE = "expandable"
VISIBLE = "visible"
LAST_DEFINED = "last_defined"
BUSY = "busy"
EXPANDED = "expanded"
MANAGES_DESCENDANTS = "manages_descendants"
IS_DEFAULT = "is_default"
INDETERMINATE = "indeterminate"
REQUIRED = "required"
TRANSIENT = "transient"
CHECKED = "checked"
SENSITIVE = "sensitive"
COLLAPSED = "collapsed"
STALE = "stale"
OPAQUE = "opaque"
ENABLED = "enabled"
HAS_TOOLTIP = "has_tooltip"
SUPPORTS_AUTOCOMPLETION = "supports_autocompletion"
FOCUSABLE = "focusable"
SELECTABLE = "selectable"
ACTIVE = "active"
HORIZONTAL = "horizontal"
VISITED = "visited"
INVALID_ENTRY = "invalid_entry"
FOCUSED = "focused"
MODAL = "modal"
VERTICAL = "vertical"
SELECTED = "selected"
SHOWING = "showing"
ANIMATED = "animated"
EDITABLE = "editable"
MULTI_LINE = "multi_line"
SINGLE_LINE = "single_line"
SELECTABLE_TEXT = "selectable_text"
ARMED = "armed"
DEFUNCT = "defunct"
MULTISELECTABLE = "multiselectable"
RESIZABLE = "resizable"
TRUNCATED = "truncated"

==> ldtp_2.3.1.orig.tar.gz: ldtp-2.3.1/ldtp/state.py <==
"""
LDTP v2 client

@author: Nagappan Alagappan <nagappan@gmail.com>
@copyright: Copyright (c) 2009-12 Nagappan Alagappan
@license: LGPL

http://ldtp.freedesktop.org

This file may be distributed and/or modified under the terms of the GNU Lesser General
Public License version 2 as published by the Free Software Foundation. This file
is distributed without any warranty; without even the implied warranty of 
merchantability or fitness for a particular purpose.

See 'COPYING' in the source distribution for more information.

Headers in this file shall remain intact.
"""

ICONIFIED = "iconified"
INVALID = "invalid"
PRESSED = "pressed"
EXPANDABLE = "expandable"
VISIBLE = "visible"
LAST_DEFINED = "last_defined"
BUSY = "busy"
EXPANDED = "expanded"
MANAGES_DESCENDANTS = "manages_descendants"
IS_DEFAULT = "is_default"
INDETERMINATE = "indeterminate"
REQUIRED = "required"
TRANSIENT = "transient"
CHECKED = "checked"
SENSITIVE = "sensitive"
COLLAPSED = "collapsed"
STALE = "stale"
OPAQUE = "opaque"
ENABLED = "enabled"
HAS_TOOLTIP = "has_tooltip"
SUPPORTS_AUTOCOMPLETION = "supports_autocompletion"
FOCUSABLE = "focusable"
SELECTABLE = "selectable"
ACTIVE = "active"
HORIZONTAL = "horizontal"
VISITED = "visited"
INVALID_ENTRY = "invalid_entry"
FOCUSED = "focused"
MODAL = "modal"
VERTICAL = "vertical"
SELECTED = "selected"
SHOWING = "showing"
ANIMATED = "animated"
EDITABLE = "editable"
MULTI_LINE = "multi_line"
SINGLE_LINE = "single_line"
SELECTABLE_TEXT = "selectable_text"
ARMED = "armed"
DEFUNCT = "defunct"
MULTISELECTABLE = "multiselectable"
RESIZABLE = "resizable"
TRUNCATED = "truncated"
